{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G MMM y",
    GyMMMEd => "G, d MMM, y, E",
    GyMMMd => "G d, MMM y",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "d/M, E",
    MMM => "LLL",
    MMMEd => "d MMM, E",
    "MMMMW-count-one" => "MMMM\N{U+0c32}\N{U+0c4b} W\N{U+0c35} \N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "MMMMW-count-other" => "MMMM\N{U+0c32}\N{U+0c4b} W\N{U+0c35} \N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd-MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "d/M/y, E",
    yMM => "MM-y",
    yMMM => "MMM y",
    yMMMEd => "d MMM, y, E",
    yMMMM => "MMMM y",
    yMMMd => "d, MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y\N{U+0c32}\N{U+0c4b} w\N{U+0c35} \N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "yw-count-other" => "Y\N{U+0c32}\N{U+0c4b} w\N{U+0c35} \N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
  },
  code => "te-IN",
  date_format_full => "d, MMMM y, EEEE",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "dd-MM-yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0c38}\N{U+0c4b}\N{U+0c2e}",
    "\N{U+0c2e}\N{U+0c02}\N{U+0c17}\N{U+0c33}",
    "\N{U+0c2c}\N{U+0c41}\N{U+0c27}",
    "\N{U+0c17}\N{U+0c41}\N{U+0c30}\N{U+0c41}",
    "\N{U+0c36}\N{U+0c41}\N{U+0c15}\N{U+0c4d}\N{U+0c30}",
    "\N{U+0c36}\N{U+0c28}\N{U+0c3f}",
    "\N{U+0c06}\N{U+0c26}\N{U+0c3f}",
  ],
  day_format_narrow => [
    "\N{U+0c38}\N{U+0c4b}",
    "\N{U+0c2e}",
    "\N{U+0c2c}\N{U+0c41}",
    "\N{U+0c17}\N{U+0c41}",
    "\N{U+0c36}\N{U+0c41}",
    "\N{U+0c36}",
    "\N{U+0c06}",
  ],
  day_format_wide => [
    "\N{U+0c38}\N{U+0c4b}\N{U+0c2e}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c2e}\N{U+0c02}\N{U+0c17}\N{U+0c33}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c2c}\N{U+0c41}\N{U+0c27}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c17}\N{U+0c41}\N{U+0c30}\N{U+0c41}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c36}\N{U+0c41}\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c36}\N{U+0c28}\N{U+0c3f}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c06}\N{U+0c26}\N{U+0c3f}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0c38}\N{U+0c4b}\N{U+0c2e}",
    "\N{U+0c2e}\N{U+0c02}\N{U+0c17}\N{U+0c33}",
    "\N{U+0c2c}\N{U+0c41}\N{U+0c27}",
    "\N{U+0c17}\N{U+0c41}\N{U+0c30}\N{U+0c41}",
    "\N{U+0c36}\N{U+0c41}\N{U+0c15}\N{U+0c4d}\N{U+0c30}",
    "\N{U+0c36}\N{U+0c28}\N{U+0c3f}",
    "\N{U+0c06}\N{U+0c26}\N{U+0c3f}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0c38}\N{U+0c4b}",
    "\N{U+0c2e}",
    "\N{U+0c2c}\N{U+0c41}",
    "\N{U+0c17}\N{U+0c41}",
    "\N{U+0c36}\N{U+0c41}",
    "\N{U+0c36}",
    "\N{U+0c06}",
  ],
  day_stand_alone_wide => [
    "\N{U+0c38}\N{U+0c4b}\N{U+0c2e}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c2e}\N{U+0c02}\N{U+0c17}\N{U+0c33}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c2c}\N{U+0c41}\N{U+0c27}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c17}\N{U+0c41}\N{U+0c30}\N{U+0c41}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c36}\N{U+0c41}\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c36}\N{U+0c28}\N{U+0c3f}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
    "\N{U+0c06}\N{U+0c26}\N{U+0c3f}\N{U+0c35}\N{U+0c3e}\N{U+0c30}\N{U+0c02}",
  ],
  era_abbreviated => [
    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c2a}\N{U+0c42}",
    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c36}",
  ],
  era_narrow => [
    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c2a}\N{U+0c42}",
    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c36}",
  ],
  era_wide => [
    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c38}\N{U+0c4d}\N{U+0c24}\N{U+0c41} \N{U+0c2a}\N{U+0c42}\N{U+0c30}\N{U+0c4d}\N{U+0c35}\N{U+0c02}",
    "\N{U+0c15}\N{U+0c4d}\N{U+0c30}\N{U+0c40}\N{U+0c38}\N{U+0c4d}\N{U+0c24}\N{U+0c41} \N{U+0c36}\N{U+0c15}\N{U+0c02}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%B %d %A %Y %p%I.%M.%S %Z",
  glibc_date_format => "%d-%m-%y",
  glibc_datetime_format => "%B %d %A %Y %p%I.%M.%S",
  glibc_time_12_format => "%p%I.%M.%S %Z",
  glibc_time_format => "%p%I.%M.%S %Z",
  language => "Telugu",
  month_format_abbreviated => [
    "\N{U+0c1c}\N{U+0c28}",
    "\N{U+0c2b}\N{U+0c3f}\N{U+0c2c}\N{U+0c4d}\N{U+0c30}",
    "\N{U+0c2e}\N{U+0c3e}\N{U+0c30}\N{U+0c4d}\N{U+0c1a}\N{U+0c3f}",
    "\N{U+0c0f}\N{U+0c2a}\N{U+0c4d}\N{U+0c30}\N{U+0c3f}",
    "\N{U+0c2e}\N{U+0c47}",
    "\N{U+0c1c}\N{U+0c42}\N{U+0c28}\N{U+0c4d}",
    "\N{U+0c1c}\N{U+0c41}\N{U+0c32}\N{U+0c48}",
    "\N{U+0c06}\N{U+0c17}",
    "\N{U+0c38}\N{U+0c46}\N{U+0c2a}\N{U+0c4d}\N{U+0c1f}\N{U+0c46}\N{U+0c02}",
    "\N{U+0c05}\N{U+0c15}\N{U+0c4d}\N{U+0c1f}\N{U+0c4b}",
    "\N{U+0c28}\N{U+0c35}\N{U+0c02}",
    "\N{U+0c21}\N{U+0c3f}\N{U+0c38}\N{U+0c46}\N{U+0c02}",
  ],
  month_format_narrow => [
    "\N{U+0c1c}",
    "\N{U+0c2b}\N{U+0c3f}",
    "\N{U+0c2e}\N{U+0c3e}",
    "\N{U+0c0f}",
    "\N{U+0c2e}\N{U+0c47}",
    "\N{U+0c1c}\N{U+0c42}",
    "\N{U+0c1c}\N{U+0c41}",
    "\N{U+0c06}",
    "\N{U+0c38}\N{U+0c46}",
    "\N{U+0c05}",
    "\N{U+0c28}",
    "\N{U+0c21}\N{U+0c3f}",
  ],
  month_format_wide => [
    "\N{U+0c1c}\N{U+0c28}\N{U+0c35}\N{U+0c30}\N{U+0c3f}",
    "\N{U+0c2b}\N{U+0c3f}\N{U+0c2c}\N{U+0c4d}\N{U+0c30}\N{U+0c35}\N{U+0c30}\N{U+0c3f}",
    "\N{U+0c2e}\N{U+0c3e}\N{U+0c30}\N{U+0c4d}\N{U+0c1a}\N{U+0c3f}",
    "\N{U+0c0f}\N{U+0c2a}\N{U+0c4d}\N{U+0c30}\N{U+0c3f}\N{U+0c32}\N{U+0c4d}",
    "\N{U+0c2e}\N{U+0c47}",
    "\N{U+0c1c}\N{U+0c42}\N{U+0c28}\N{U+0c4d}",
    "\N{U+0c1c}\N{U+0c41}\N{U+0c32}\N{U+0c48}",
    "\N{U+0c06}\N{U+0c17}\N{U+0c38}\N{U+0c4d}\N{U+0c1f}\N{U+0c41}",
    "\N{U+0c38}\N{U+0c46}\N{U+0c2a}\N{U+0c4d}\N{U+0c1f}\N{U+0c46}\N{U+0c02}\N{U+0c2c}\N{U+0c30}\N{U+0c4d}",
    "\N{U+0c05}\N{U+0c15}\N{U+0c4d}\N{U+0c1f}\N{U+0c4b}\N{U+0c2c}\N{U+0c30}\N{U+0c4d}",
    "\N{U+0c28}\N{U+0c35}\N{U+0c02}\N{U+0c2c}\N{U+0c30}\N{U+0c4d}",
    "\N{U+0c21}\N{U+0c3f}\N{U+0c38}\N{U+0c46}\N{U+0c02}\N{U+0c2c}\N{U+0c30}\N{U+0c4d}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0c1c}\N{U+0c28}",
    "\N{U+0c2b}\N{U+0c3f}\N{U+0c2c}\N{U+0c4d}\N{U+0c30}",
    "\N{U+0c2e}\N{U+0c3e}\N{U+0c30}\N{U+0c4d}\N{U+0c1a}\N{U+0c3f}",
    "\N{U+0c0f}\N{U+0c2a}\N{U+0c4d}\N{U+0c30}\N{U+0c3f}",
    "\N{U+0c2e}\N{U+0c47}",
    "\N{U+0c1c}\N{U+0c42}\N{U+0c28}\N{U+0c4d}",
    "\N{U+0c1c}\N{U+0c41}\N{U+0c32}\N{U+0c48}",
    "\N{U+0c06}\N{U+0c17}",
    "\N{U+0c38}\N{U+0c46}\N{U+0c2a}\N{U+0c4d}\N{U+0c1f}\N{U+0c46}\N{U+0c02}",
    "\N{U+0c05}\N{U+0c15}\N{U+0c4d}\N{U+0c1f}\N{U+0c4b}",
    "\N{U+0c28}\N{U+0c35}\N{U+0c02}",
    "\N{U+0c21}\N{U+0c3f}\N{U+0c38}\N{U+0c46}\N{U+0c02}",
  ],
  month_stand_alone_narrow => [
    "\N{U+0c1c}",
    "\N{U+0c2b}\N{U+0c3f}",
    "\N{U+0c2e}\N{U+0c3e}",
    "\N{U+0c0f}",
    "\N{U+0c2e}\N{U+0c47}",
    "\N{U+0c1c}\N{U+0c42}",
    "\N{U+0c1c}\N{U+0c41}",
    "\N{U+0c06}",
    "\N{U+0c38}\N{U+0c46}",
    "\N{U+0c05}",
    "\N{U+0c28}",
    "\N{U+0c21}\N{U+0c3f}",
  ],
  month_stand_alone_wide => [
    "\N{U+0c1c}\N{U+0c28}\N{U+0c35}\N{U+0c30}\N{U+0c3f}",
    "\N{U+0c2b}\N{U+0c3f}\N{U+0c2c}\N{U+0c4d}\N{U+0c30}\N{U+0c35}\N{U+0c30}\N{U+0c3f}",
    "\N{U+0c2e}\N{U+0c3e}\N{U+0c30}\N{U+0c4d}\N{U+0c1a}\N{U+0c3f}",
    "\N{U+0c0f}\N{U+0c2a}\N{U+0c4d}\N{U+0c30}\N{U+0c3f}\N{U+0c32}\N{U+0c4d}",
    "\N{U+0c2e}\N{U+0c47}",
    "\N{U+0c1c}\N{U+0c42}\N{U+0c28}\N{U+0c4d}",
    "\N{U+0c1c}\N{U+0c41}\N{U+0c32}\N{U+0c48}",
    "\N{U+0c06}\N{U+0c17}\N{U+0c38}\N{U+0c4d}\N{U+0c1f}\N{U+0c41}",
    "\N{U+0c38}\N{U+0c46}\N{U+0c2a}\N{U+0c4d}\N{U+0c1f}\N{U+0c46}\N{U+0c02}\N{U+0c2c}\N{U+0c30}\N{U+0c4d}",
    "\N{U+0c05}\N{U+0c15}\N{U+0c4d}\N{U+0c1f}\N{U+0c4b}\N{U+0c2c}\N{U+0c30}\N{U+0c4d}",
    "\N{U+0c28}\N{U+0c35}\N{U+0c02}\N{U+0c2c}\N{U+0c30}\N{U+0c4d}",
    "\N{U+0c21}\N{U+0c3f}\N{U+0c38}\N{U+0c46}\N{U+0c02}\N{U+0c2c}\N{U+0c30}\N{U+0c4d}",
  ],
  name => "Telugu India",
  native_language => "\N{U+0c24}\N{U+0c46}\N{U+0c32}\N{U+0c41}\N{U+0c17}\N{U+0c41}",
  native_name => "\N{U+0c24}\N{U+0c46}\N{U+0c32}\N{U+0c41}\N{U+0c17}\N{U+0c41} \N{U+0c2d}\N{U+0c3e}\N{U+0c30}\N{U+0c24}\N{U+0c26}\N{U+0c47}\N{U+0c36}\N{U+0c02}",
  native_script => undef,
  native_territory => "\N{U+0c2d}\N{U+0c3e}\N{U+0c30}\N{U+0c24}\N{U+0c26}\N{U+0c47}\N{U+0c36}\N{U+0c02}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}1",
    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}2",
    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}3",
    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
    "2\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
    "3\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
    "4\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}1",
    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}2",
    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}3",
    "\N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
    "2\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
    "3\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
    "4\N{U+0c35} \N{U+0c24}\N{U+0c4d}\N{U+0c30}\N{U+0c48}\N{U+0c2e}\N{U+0c3e}\N{U+0c38}\N{U+0c3f}\N{U+0c15}\N{U+0c02}",
  ],
  script => undef,
  territory => "India",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 42,
}
